@@ -39,7 +39,7 @@ def upload_dataframe(presigned_url: str, df, name: str) -> None:
         path = f"{temp_dir}/{name}"
         df_type = f"{type(df).__module__}.{type(df).__name__}"
         if df_type == "pandas.core.frame.DataFrame":
-            df.to_csv(path)
+            df.to_csv(path, index=False)
         upload_temp_file(path, presigned_url)
 
 
